@@ -21,10 +21,11 @@ from Cheetah.Template import Template
 
 class Interface(object):
 
-    def __init__(self, interface, servername, port):
+    def __init__(self, interface, servername, port, ssl = None):
         self.interface = interface
         self.servername = servername
         self.port = port
+        self.ssl = ssl
 
 class Emergency(object):
 
@@ -41,6 +42,13 @@ class Emergency(object):
         self.options.setdefault('error_log', os.path.join(outputdir, "error.log"))
         self.options.setdefault('template', os.path.join(os.path.dirname(__file__), "apache.conf"))
         self.options.setdefault('listen', 'no')
+        self.options.setdefault('namevirtualhost', self.options['listen'])
+        self.options.setdefault('sslca', '')
+
+        if self.options.get("enhanced-privacy", None):
+            options.setdefault("logformat", '"0.0.0.0 %l %u %t \\"%r\\" %>s %b \\"%{Referer}i\\" \\"%{User-agent}i\\""')
+        else:
+            options.setdefault("logformat", "Combined")
 
     def install(self):
         outputdir = os.path.join(self.buildout['buildout']['directory'], self.name)
@@ -57,6 +65,7 @@ class Emergency(object):
         vars = self.options.copy()
         vars.update({
             'listen': self.options['listen'] == 'yes',
+            'namevirtualhost': self.options['namevirtualhost'] == 'yes',
             'interfaces': [Interface(*x.split(":")) for x in self.options['interfaces'].strip().split()],
         })
         t = Template(open(self.options['template']).read(), searchList=vars)
